gossan-cloud 0.3.3

Cloud asset discovery scanner for gossan (S3, GCS, Azure Blob, DigitalOcean Spaces), part of the security research ecosystem
docs.rs failed to build gossan-cloud-0.3.3
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: gossan-cloud-0.3.2

gossan-cloud

Part of the Santh security research ecosystem.

Cloud asset discovery scanner for gossan (S3, GCS, Azure Blob, DigitalOcean Spaces) (part of the Santh security research ecosystem).

Part of gossan.

Usage

## Usage

```rust
use gossan_cloud::{CloudScanner, ScanInput};
use gossan_core::{Config, Target, DomainTarget, DiscoverySource};

#[tokio::main]
async fn main() {
    let scanner = CloudScanner;
    let target = Target::Domain(DomainTarget {
        domain: "example.com".into(),
        source: DiscoverySource::Seed,
    });
    
    let input = ScanInput {
        seed: "example.com".into(),
        targets: vec![target],
        live_tx: None,
        target_tx: None,
    };
    
    let output = scanner.run(input, &Config::default()).await.unwrap();
    println!("Found {} cloud assets", output.targets.len());
}

## License

MIT